@@ -1,5 +1,6 @@
-"""Operators that work on slabs.
-Allowed compositions are respected.
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+"""Operators that work on slabs. Allowed compositions are respected.
 Identical indexing of the slabs are assumed for the cut-splice operator."""
 import random
 from operator import itemgetter
@@ -7,7 +8,6 @@ from collections import Counter
 from itertools import permutations
 import numpy as np
 from ase.ga.offspring_creator import OffspringCreator
-from ase.ga.element_mutations import get_row_column
 
 
 def permute2(atoms):
